@@ -272,7 +272,7 @@ SUSE_PKG_MAP = [
             'ironic-inspector-', 'karbor', 'k8s', 'keystone',
             'magnum', 'manila', 'masakari', 'mistral', 'monasca',
             'murano', 'nimble', 'neutron', 'nova', 'oneview',
-            'openstack', 'sahara', 'scci', 'searchlight', 'senlin',
+            'openstack', 'qinling', 'sahara', 'scci', 'searchlight', 'senlin',
             'smaug', 'solum', 'swift', 'tacker', 'tripleo', 'trove',
             'vitrage', 'watcher', 'zaqar')],
         pkgfun=subst_python2_python3),
@@ -317,7 +317,7 @@ UBUNTU_PKG_MAP = [
             'karbor',  'keystone',
             'magnum', 'manila', 'masakari', 'mistral', 'monasca',
             'murano', 'neutron', 'nova',
-            'openstack', 'sahara',
+            'openstack', 'qinling', 'sahara',
             'senlin', 'swift',
             'trove',  'zaqar')],
         pkgfun=same_name_python_subst_python3),
